@@ -22,7 +22,7 @@ use Carp;
 use Excel::Writer::XLSX::Chart;
 
 our @ISA     = qw(Excel::Writer::XLSX::Chart);
-our $VERSION = '0.77';
+our $VERSION = '0.81';
 
 
 ###############################################################################
@@ -46,6 +46,10 @@ sub new {
 
     $self->set_y_axis();
 
+    # Sset the available data label positions for this chart type.
+    $self->{_label_position_default} = 'center';
+    $self->{_label_positions} = { center => 'ctr' };
+
     bless $self, $class;
     return $self;
 }
@@ -242,7 +246,7 @@ Here is a complete example that demonstrates most of the available features when
 
 <p>This will produce a chart that looks like this:</p>
 
-<p><center><img src="http://jmcnamara.github.com/excel-writer-xlsx/images/examples/area1.jpg" width="483" height="291" alt="Chart example." /></center></p>
+<p><center><img src="http://jmcnamara.github.io/excel-writer-xlsx/images/examples/area1.jpg" width="483" height="291" alt="Chart example." /></center></p>
 
 =end html
 
